# [drfhumplib](https://pypi.org/project/humplib/#description)
python drfhumplib lib

* parses(解析器)
    * SnakeJSONParser
    * UnderlineParser(解析驼峰的请求到下划线)
    
* renders(渲染器)
    * HumpJSONRenderer(渲染下划线响应到驼峰响应)

```shell
pip install -i https://pypi.org/simple  drfhumplib==0.1.1

```

## 国内镜像仓库

```
https://pypi.org/simple
https://pypi.tuna.tsinghua.edu.cn/simple/drfhumplib/

pip install -i https://pypi.org/simple  drfhumplib
```


